public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] proj/R_overlay:master commit in: roverlay/overlay/manifest/
@ 2012-08-02 15:14 André Erdmann
  0 siblings, 0 replies; only message in thread
From: André Erdmann @ 2012-08-02 15:14 UTC (permalink / raw
  To: gentoo-commits

commit:     f86187ff5e6bb95ed3f0d7f159e32c378e984565
Author:     André Erdmann <dywi <AT> mailerd <DOT> de>
AuthorDate: Thu Aug  2 14:56:24 2012 +0000
Commit:     André Erdmann <dywi <AT> mailerd <DOT> de>
CommitDate: Thu Aug  2 14:56:24 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/R_overlay.git;a=commit;h=f86187ff

Manifest: use strutil, not util

---
 roverlay/overlay/manifest/helpers.py |   10 ++++------
 1 files changed, 4 insertions(+), 6 deletions(-)

diff --git a/roverlay/overlay/manifest/helpers.py b/roverlay/overlay/manifest/helpers.py
index d49ecf7..fe31119 100644
--- a/roverlay/overlay/manifest/helpers.py
+++ b/roverlay/overlay/manifest/helpers.py
@@ -12,7 +12,7 @@ import logging
 import subprocess
 
 
-from roverlay import config, util
+from roverlay import config, strutil
 
 from roverlay.overlay.manifest.env import ManifestEnv
 
@@ -54,8 +54,6 @@ class ExternalManifestCreation ( object ):
 
 		self.manifest_env ['PORTAGE_RO_DISTDIRS'] = distdirs
 
-		#util.dodir ( self.manifest_env ['DISTDIR'] )
-
 		ebuild_call = subprocess.Popen (
 			(
 				self.ebuild_prog,
@@ -71,12 +69,12 @@ class ExternalManifestCreation ( object ):
 		output = ebuild_call.communicate()
 
 		# log stdout?
 		#for line in util.pipe_lines ( output [0] ):
 		#	LOGGER.debug ( line )
 		#for line in util.pipe_lines ( output [0] ): print ( line )
 
 		# log stderr
-		for line in util.pipe_lines ( output [1], use_filter=True ):
+		for line in strutil.pipe_lines ( output [1], use_filter=True ):
 			self.logger.warning ( line )
 
 		if ebuild_call.returncode == 0:


^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2012-08-02 15:15 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -71,12 +69,12 @@ class ExternalManifestCreation ( object ):
 
 		# log stdout?
-		#for line in util.pipe_lines ( output [0] ):
+		#for line in strutil.pipe_lines ( output [0] ):
 		#	LOGGER.debug ( line )
@@ -71,12 +69,12 @@ class ExternalManifestCreation ( object ):
 		#	LOGGER.debug ( line )
-		#for line in util.pipe_lines ( output [0] ): print ( line )
+		#for line in strutil.pipe_lines ( output [0] ): print ( line )
 
 		# log stderr
2012-08-02 15:14 [gentoo-commits] proj/R_overlay:master commit in: roverlay/overlay/manifest/ André Erdmann

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox